import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A world for experimentation in the consequences of dots running around and
 * interacting with each other.
 * 
 * @author Marla Parker 
 * @version March 11, 2009
 */
public class PetriDish extends World
{
    /*
     * Total number of possible Dot colors.
     */    
    private final static int ROYGBIV = 7;
    
    /*
     * Later plan to make these user controls, but for now they are just
     * fields set at compile time.
     */
    
    /*
     * Should all the dots of the same color start out moving in the same 
     * direction?
     */
    private boolean dirByColor = true;
    
    /*
     * Should the dots bounce off the walls or go right "through" to the 
     * other side?
     */
    private boolean wallBounce = true;
    
    /*
     * Create a new world with 300x300 cells with a cell size of 2x2 pixels
     * and populate it with some number of dots.
     */
    public PetriDish()
    {    
        super(150, 150, 2);
                
        populate(50);
    }
    
    /*
     * Populate the PetriDish with some dots.  Code based on the populate method
     * from the Boids scenario.
     */
    private void populate(int number) {     
        Dot.resetNextId();
        for(int i=0; i < number; i++) {            
             int x = (int) (Math.random() * getWidth());          
             int y = (int) (Math.random() * getHeight());
             int c = (int) (Math.random() * ROYGBIV);
             Dot d = new Dot(c, dirByColor);
             addObject(d, x, y);
        }
    }
    
    
    /*
     * Set dirByColor
     */
    public void setDirByColor(boolean val) {
        dirByColor = val;
    }
    
    /*
     * Get dirByColor
     */
    public boolean getDirByColor() {
        return dirByColor;
    }
    
    /*
     * set wallBounce
     */
    public void setWallBounce(boolean val) {
        wallBounce = val;
    }
    
    /*
     * get wallBounce
     */
    public boolean getWallBounce() {
        return wallBounce;
    }    
}
